@@ -131,6 +131,16 @@ int nfnl_fd(struct nfnl_handle *h)
 	return h->fd;
 }
 
+/**
+ * nfnl_portid - returns the Netlink port ID of this socket
+ * @h: nfnetlink handler
+ */
+unsigned int nfnl_portid(const struct nfnl_handle *h)
+{
+	assert(h);
+	return h->local.nl_pid;
+}
+
 static int recalc_rebind_subscriptions(struct nfnl_handle *nfnlh)
 {
 	int i, err;
@@ -842,6 +852,23 @@ int nfnl_nfa_addattr_l(struct nfattr *nfa, int maxlen, int type,
 	return 0;
 }
 
+/**
+ * nfnl_addattr8 - Add u_int8_t attribute to nlmsghdr
+ *
+ * @n: netlink message header to which attribute is to be added
+ * @maxlen: maximum length of netlink message header
+ * @type: type of new attribute
+ * @data: content of new attribute
+ */
+int nfnl_addattr8(struct nlmsghdr *n, int maxlen, int type, u_int8_t data)
+{
+	assert(n);
+	assert(maxlen > 0);
+	assert(type >= 0);
+
+	return nfnl_addattr_l(n, maxlen, type, &data, sizeof(data));
+}
+
 /**
  * nfnl_nfa_addattr16 - Add u_int16_t attribute to struct nfattr 
  *
